import { SIZE_OF_EMPTY_ARRAY } from '@/constants/common';
import { FEATURE_TYPE, PIN_ICON_ANY, SURFACE_ANY } from '@/constants/features';
import { openBioEntityDrawerById } from '@/redux/drawer/drawer.slice';
import { AppDispatch } from '@/redux/store';
import { PluginsEventBus } from '@/services/pluginsManager/pluginsEventBus';
import { FeatureLike } from 'ol/Feature';

interface HandleFeaturesClickResult {
  shouldBlockCoordSearch: boolean;
}

export const handleFeaturesClick = (
  features: FeatureLike[],
  dispatch: AppDispatch,
): HandleFeaturesClickResult => {
  const pinFeatures = features.filter(feature => PIN_ICON_ANY.includes(feature.get('type')));
  const surfaceFeatures = features.filter(feature => SURFACE_ANY.includes(feature.get('type')));
  const shouldBlockCoordSearch = pinFeatures.length > SIZE_OF_EMPTY_ARRAY;

  pinFeatures.forEach(pin => {
    const pinId = pin.get('id') as string | number;
    PluginsEventBus.dispatchEvent('onPinIconClick', { id: pinId });

    if (pin.get('type') === FEATURE_TYPE.PIN_ICON_BIOENTITY) {
      dispatch(openBioEntityDrawerById(pinId));
    }
  });

  surfaceFeatures.forEach(surface => {
    const surfaceId = surface.get('id') as string | number;
    PluginsEventBus.dispatchEvent('onSurfaceClick', { id: surfaceId });
  });

  return {
    shouldBlockCoordSearch,
  };
};
